.. mdinclude:: readme.rst

.. toctree::
   :hidden:
   :maxdepth: 2

   Overview <readme>
   installation

.. toctree::
   :caption: User Guides
   :hidden:

   maintainer_guide
   contributor_guide
   feature_engineering_guide
   faq

.. toctree::
   :caption: Reference
   :hidden:

   API Reference <api/ballet>
   CLI Reference <cli_reference>

.. toctree::
   :caption: Development Notes
   :hidden:

   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
